@@ -180,7 +180,7 @@ def window():
     logger.info('=====欢迎来到基于ARIMA改进GM(1,1)模型软件2.0==========\n=======================')
 
     win.title('基于ARIMA改进GM(1,1)模型软件2.0')
-    win.iconphoto(False, tk.PhotoImage(file='need/1.png'))
+    #win.iconphoto(False, tk.PhotoImage(file='need/1.png'))
     win.columnconfigure(0,weight = 1)
     win.rowconfigure(0,weight = 1)
     win.columnconfigure(1,weight = 1)
